yakumo.neutron.v2.quota.Resource

Package yakumo :: Package neutron :: Package v2 :: Module quota :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

Resource class for quotas in Networking V2 API

Instance Methods | [hide private]
None |
update(self, subnet=`'``__UNDEF__``'`, ikepolicy=`'``__UNDEF__``'`, subnetpool=`'``__UNDEF__``'`, network=`'``__UNDEF__``'`, ipsec_site_connection=`'``__UNDEF__``'`, floatingip=`'``__UNDEF__``'`, ipsecpolicy=`'``__UNDEF__``'`, security_group_rule=`'``__UNDEF__``'`, vpnservice=`'``__UNDEF__``'`, security_group=`'``__UNDEF__``'`, router=`'``__UNDEF__``'`, port=`'``__UNDEF__``'`) Update properties of a quota | source code
None |
delete(self) Delete a resource | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, subnet=`'``__UNDEF__``'`, ikepolicy=`'``__UNDEF__``'`, subnetpool=`'``__UNDEF__``'`, network=`'``__UNDEF__``'`, ipsec_site_connection=`'``__UNDEF__``'`, floatingip=`'``__UNDEF__``'`, ipsecpolicy=`'``__UNDEF__``'`, security_group_rule=`'``__UNDEF__``'`, vpnservice=`'``__UNDEF__``'`, security_group=`'``__UNDEF__``'`, router=`'``__UNDEF__``'`, port=`'``__UNDEF__``'`) | source code
Update properties of a quota Parameters: `subnet` (int) - Maximum number of subnets `ikepolicy` (int) - Maximum number of IKE policies `subnetpool` (int) - Maximum number of subnet pools `network` (int) - Maximum number of networks `ipsec_site_connection` (int) - Maximum number of IPSec site connections `floatingip` (int) - Maximum number of floating IPs `ipsecpolicy` (int) - Maximum number of IPSec policies `security_group_rule` (int) - Maximum number of security group rules `vpnservice` (int) - Maximum number of VPN services `security_group` (int) - Maximum number of security groups `router` (int) - Maximum number of routers `port` (int) - Maximum number of ports Returns: None Overrides: base.Resource.update

### delete(self) | source code
Delete a resource Returns: None Overrides: base.Resource.delete (inherited documentation)